<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-eo',
'0_langue' => 'Esperanto [eo]',
'0_liste' => 'spip-eo@rezo.net',
'0_mainteneur' => 'MHSautet@aol.com',

// A
'access_interface_graphique' => 'Reen al kompleta grafika interfaco',
'access_mode_texte' => 'Afi&#349;i la simpligitan tekstan interfacon',
'admin_debug' => 'erarser&#265;ilo',
'admin_modifier_article' => 'Modifu tiun &#265;i artikolon',
'admin_modifier_auteur' => 'Modifu tiun &#265;i a&#365;toron',
'admin_modifier_breve' => 'Modifu tiun &#265;i fulm-informon',
'admin_modifier_mot' => 'Modifu tiun &#265;i &#349;losilvorton',
'admin_modifier_rubrique' => 'Modifu tiun &#265;i rubrikon',
'admin_recalculer' => 'Rekalkulu tiun &#265;i pa&#285;on',
'afficher_trad' => 'afi&#349;i la tradukojn',
'alerte_maj_impossible' => '<b>Alarmo&nbsp;!</b> La &#285;isdatigo de la SQL-datenbazo al versio @version@ ne eblas pro datenbazo-modif-rajtaj kialoj. Bonvolu kontakti vian retgastiganton.',
'alerte_modif_info_concourante' => 'ATENTU : Tiu &#265;i informo estis modifita de alia homo. La nuna stato estas&nbsp;:', # MODIF
'analyse_xml' => 'XML analizo',
'annuler' => 'Nuligi',
'antispam_champ_vide' => 'Bonvolu forlasi tiun tajpujon malplena&nbsp;:',
'articles_recents' => 'La plej fre&#349;aj artikoloj',
'avis_archive_incorrect' => 'Tiu arkivo ne estas SPIP-dosiero',
'avis_archive_invalide' => 'Tiu arkiva dosiero ne validas',
'avis_attention' => 'ATENTU&nbsp;!',
'avis_champ_incorrect_type_objet' => 'Erara tajpuja nomo @name@ por la objekto de tipo @type@',
'avis_colonne_inexistante' => 'La kolumno @col@ ne ekzistas',
'avis_echec_syndication_01' => 'Abonligo malsukcesis: la indikata abondosiero (backend-dosiero) ne estas de&#265;ifrebla a&#365; proponas neniun artikolon.',
'avis_echec_syndication_02' => 'Abonligo malsukcesis: ne eblas aliri abondosieron (backend-dosiero) de tiu retejo.',
'avis_erreur' => 'Eraro: vidu &#265;i-sube',
'avis_erreur_connexion' => 'Konekt-eraro',
'avis_erreur_cookie' => 'kuketo-problemo',
'avis_erreur_fonction_contexte' => 'Program-eraro. Tiu funkcio ne alvokeblas en tiu &#265;i kunteksto.',
'avis_erreur_mysql' => 'SQL-eraro',
'avis_erreur_sauvegarde' => 'Konservo-eraro (@type@ @id_objet@)! ',
'avis_erreur_visiteur' => 'Alir-problemo al la privata spaco',

// B
'barre_a_accent_grave' => 'Entajpi malakut-akcentan &#265;efliteran A',
'barre_aide' => 'Uzu la tipografiajn rapidligilojn por pliri&#265;igi vian enpa&#285;igon',
'barre_e_accent_aigu' => 'Entajpi malakut-akcentan &#265;efliteran E',
'barre_eo' => 'Entajpi E en &#265;efliteran O',
'barre_eo_maj' => 'Entajpi E en la &#265;eflitero O',
'barre_euro' => 'Entajpi la simbolon &euro;',
'barre_gras' => '{{Grasigi}}',
'barre_guillemets' => 'Flanki per &laquo; citiloj &raquo;',
'barre_guillemets_simples' => 'Flanki per &#147;simplaj citiloj&#148;',
'barre_intertitre' => '{{{Intertitoligi}}}',
'barre_italic' => '{Kursivigi}',
'barre_lien' => 'Transformi al [hiperligo->http://...]',
'barre_lien_input' => 'Bonvolu indiki la retadreson de via ligilo (vi povas indiki ret-adreson tian, kia http://www.monsite.com a&#365; simple indiki la numeron de artikolo de tiu retejo.',
'barre_note' => 'Transformi al [[sub-pa&#285;an noton]]',
'barre_paragraphe' => 'Krei paragrafon',
'barre_quote' => '<quote>Citi mesa&#285;on</quote>',
'bouton_ajouter_document' => 'ALDONI DOKUMENTON', # MODIF
'bouton_ajouter_image' => 'ALDONI BILDON', # MODIF
'bouton_ajouter_image_document' => 'Aldoni bildon a&#365; dokumenton',
'bouton_changer' => '&#348;an&#285;i',
'bouton_chercher' => 'Ser&#265;i',
'bouton_choisir' => 'Elekti',
'bouton_download' => 'El&#349;uti',
'bouton_enregistrer' => 'Registri',
'bouton_radio_desactiver_messagerie_interne' => 'Mal&#349;alti la internan mesa&#285;ilon',
'bouton_radio_envoi_annonces' => 'Sendi la &#265;efartikolajn anoncojn',
'bouton_radio_non_envoi_annonces' => 'Ne sendi anoncojn',
'bouton_radio_non_envoi_liste_nouveautes' => 'Ne sendi liston de nova&#309;oj',
'bouton_recharger_page' => 'fre&#349;igi tiun pa&#285;on',
'bouton_telecharger' => 'Al&#349;uti',
'bouton_valider' => 'Validigi',

// C
'cal_apresmidi' => 'posttagmezo',
'cal_jour_entier' => 'tuta tago',
'cal_matin' => 'mateno',
'cal_par_jour' => 'tag-kalendaro',
'cal_par_mois' => 'monat-kalendaro',
'cal_par_semaine' => 'semajn-kalendaro',
'choix_couleur_interface' => 'koloro',
'choix_interface' => 'elekto de interfaco',
'colonne' => 'Kolumno',
'confirm_changer_statut' => 'Atentu, vi petis por &#349;an&#285;i la statuton de tiu elemento. &#264;u vi deziras da&#365;rigi ?',
'correcte' => 'korekta',

// D
'date_aujourdhui' => 'hodia&#365;',
'date_avant_jc' => 'a.K.',
'date_dans' => 'post @delai@',
'date_de_mois_1' => '@j@ @nommois@',
'date_de_mois_10' => '@j@ @nommois@',
'date_de_mois_11' => '@j@ @nommois@',
'date_de_mois_12' => '@j@ @nommois@',
'date_de_mois_2' => '@j@ @nommois@',
'date_de_mois_3' => '@j@ @nommois@',
'date_de_mois_4' => '@j@ @nommois@',
'date_de_mois_5' => '@j@ @nommois@',
'date_de_mois_6' => '@j@ @nommois@',
'date_de_mois_7' => '@j@ @nommois@',
'date_de_mois_8' => '@j@ @nommois@',
'date_de_mois_9' => '@j@ @nommois@',
'date_demain' => 'morga&#365;',
'date_fmt_heures_minutes' => '@h@h@m@min',
'date_fmt_jour_heure' => '@jour@ je la @heure@',
'date_fmt_jour_mois' => '@jour@a @nommois@',
'date_fmt_jour_mois_annee' => '@jour@a @nommois@ @annee@',
'date_fmt_mois_annee' => '@nommois@ @annee@',
'date_fmt_nomjour_date' => 'la @nomjour@ @date@',
'date_heures' => 'horoj',
'date_hier' => 'hiera&#365;',
'date_il_y_a' => 'anta&#365; @delai@',
'date_jnum1' => '1',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'diman&#265;o',
'date_jour_1_abbr' => 'dim.',
'date_jour_1_initiale' => 'd.',
'date_jour_2' => 'lundo',
'date_jour_2_abbr' => 'lun.',
'date_jour_2_initiale' => 'l.',
'date_jour_3' => 'mardo',
'date_jour_3_abbr' => 'mar.',
'date_jour_3_initiale' => 'm.',
'date_jour_4' => 'merkredo',
'date_jour_4_abbr' => 'mer.',
'date_jour_4_initiale' => 'm.',
'date_jour_5' => '&#309;a&#365;do',
'date_jour_5_abbr' => 'ja&#365;.',
'date_jour_5_initiale' => 'j.',
'date_jour_6' => 'vendredo',
'date_jour_6_abbr' => 'ven.',
'date_jour_6_initiale' => 'v.',
'date_jour_7' => 'sabato',
'date_jour_7_abbr' => 'sab.',
'date_jour_7_initiale' => 's.',
'date_jours' => 'tagoj',
'date_minutes' => 'minutoj',
'date_mois' => 'monatoj',
'date_mois_1' => 'januaro',
'date_mois_10' => 'oktobro',
'date_mois_11' => 'novembro',
'date_mois_12' => 'decembro',
'date_mois_2' => 'februaro',
'date_mois_3' => 'marto',
'date_mois_4' => 'aprilo',
'date_mois_5' => 'majo',
'date_mois_6' => 'junio',
'date_mois_7' => 'julio',
'date_mois_8' => 'a&#365;gusto',
'date_mois_9' => 'septembro',
'date_saison_1' => 'vintro',
'date_saison_2' => 'printempo',
'date_saison_3' => 'somero',
'date_saison_4' => 'a&#365;tuno',
'date_secondes' => 'sekundoj',
'date_semaines' => 'semajnoj',
'date_un_mois' => 'monato',
'date_une_heure' => 'horo',
'date_une_minute' => 'minuto',
'date_une_seconde' => 'sekundo',
'date_une_semaine' => 'semajno',
'dirs_commencer' => ' por vere komenci la instalprocezon',
'dirs_preliminaire' => 'Anta&#365;faro: <b>Difinu la alir-rajtojn</b>',
'dirs_probleme_droits' => 'Alir-rajta problemo',
'dirs_repertoires_absents' => '<b>La jenaj dosierujoj ne estas trovitaj&nbsp;: <ul>@bad_dirs@.</ul> </b>
  <p>La problemo ver&#349;ajne rilatas al majuskligo de literoj.
  Kontrolu ke la majuskloj ja kongruas kun tio kio estas afi&#349;ita &#265;i-supre;
  se ili ne kongruas, bonvolu renomi la dosierujon per via FTP-programo por korekti la eraron.
</p><p>Post tio, vi povos</p>',
'dirs_repertoires_suivants' => '<b>La jenaj dosierujoj ne estas skribe modifeblaj&nbsp;: 
<ul>@bad_dirs@.</ul></b>
<p>Por solvi tion, uzu vian FTP-klienton por reguligi la alir-rajtojn de &#265;iu
 el tiuj dosierujoj. La proceduron oni detale klarigas en la instalgvidlibro.
</p><p>Post tio, vi povos </p>',
'double_occurrence' => 'Duobla trafo', # MODIF

// E
'en_cours' => 'okazanta',
'entree_dimensions' => 'Dimensioj&nbsp;:',
'entree_titre_document' => 'Titolo de la dokumento&nbsp;:',
'entree_titre_image' => 'Bildtitolo&nbsp;:',
'envoi_via_le_site' => 'Sendo tra la retejo',
'erreur' => 'Eraro',
'erreur_balise_non_fermee' => 'lasta ne fermita marko :',
'erreur_texte' => 'eraro(j)',
'etape' => 'Etapo',

// F
'fichier_introuvable' => 'Netrovebla dosiero @fichier@ ',
'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera ignor&eacute;e) :

    @url@
', # NEW
'form_deja_inscrit' => 'Vi estas jam registrita.',
'form_email_non_valide' => 'Via retpo&#349;tadreso ne validas.',
'form_forum_access_refuse' => 'Vi ne plu havas alir-rajton al tiu retejo.',
'form_forum_bonjour' => 'Saluton @nom@,',
'form_forum_email_deja_enregistre' => 'Tiu &#265;i retpo&#349;tadreso estas jam registrita, vi povas do uzi vian kutiman pasvorton.',
'form_forum_identifiant_mail' => 'Via nova ensalutilo estis &#309;us al vi sendita per retletero.',
'form_forum_identifiants' => 'Personaj ensalutiloj',
'form_forum_indiquer_nom_email' => 'Indiku &#265;i tie vian nomon kaj retpo&#349;tadreson. Via persona ensalutilo rapide alvenos al vi retletere.',
'form_forum_login' => 'salutnomo :',
'form_forum_message_auto' => '(tio estas a&#365;tomata mesa&#285;o)',
'form_forum_pass' => 'pasvorto :',
'form_forum_probleme_mail' => 'Retpo&#349;ta problemo&nbsp;: la ensalutilo ne sendeblas.',
'form_forum_voici1' => 'Jen viaj ensalutiloj por partopreni la vivon de la retejo "@nom_site_spip@" (@adresse_site@):',
'form_forum_voici2' => 'Jen estas viaj ensalutiloj por proponi artikolojn &#265;e la retejo "@nom_site_spip@" (@adresse_login@):',
'form_indiquer_email' => 'Bonvolu indiki vian retpo&#349;tadreson.',
'form_indiquer_nom' => 'Bonvolu indiki vian nomon.',
'form_indiquer_nom_site' => 'Bonvolu indiki la nomon de via retejo.',
'form_pet_adresse_site' => 'Retadreso de via retejo',
'form_pet_aucune_signature' => 'Neniu subskribo kongruas kun tiu kodo...',
'form_pet_confirmation' => 'Bonvolu konfirmi vian subskribon:',
'form_pet_deja_enregistre' => 'Tiu retejo estas jam registrita',
'form_pet_deja_signe' => 'Vi jam subskribis tiun tekston.',
'form_pet_envoi_mail_confirmation' => 'Konfirma retmesa&#285;o estis &#309;us sendita al @email@. Vi devas aliri la retadreson menciitan en tiu mesa&#285;o por validigi vian subskribon.',
'form_pet_mail_confirmation' => 'Saluton,

Vi petis subskribi la petskribon:
@titre@.

Vi entajpis jenajn informojn:
    Nomo: @nom_email@
    Retejo: @nom_site@ - @url_site@
    @message@

GRAVE...
Por validigi vian subskribon, sufi&#265;as konekti&#285;i al
la &#265;i-suba retadreso (alie via peto
estos rifuzita):

    @url@


Dankon pro via partopreno
',
'form_pet_message_commentaire' => '&#264;u mesa&#285;on, &#265;u komenton&nbsp;?',
'form_pet_nom_site2' => 'Nomo de via retejo',
'form_pet_probleme_liens' => 'Bonvolu retrakti vian mesa&#285;on forigante hiperteskajn ligilojn.',
'form_pet_probleme_technique' => 'Teknika problemo, la subskribeblo estas portempe ne ebla.',
'form_pet_signature_pasprise' => 'Via subskribo ne estas registrita.',
'form_pet_signature_validee' => 'Via subskribo estas validigita. Dankon&nbsp;!',
'form_pet_site_deja_enregistre' => 'Tiu retejo estas jam registrita',
'form_pet_url_invalide' => 'La retadreso, kiun vi indikis, ne validas.',
'form_pet_votre_email' => 'Via retpo&#349;tadreso',
'form_pet_votre_nom' => 'Via nomo a&#365; salutnomo',
'form_pet_votre_site' => 'Se vi havas retejon, vi povas &#285;in indiki &#265;i-sube',
'form_prop_confirmer_envoi' => 'Konfirmi la sendon',
'form_prop_description' => 'Priskribo/komento',
'form_prop_enregistre' => 'Via kontribuo estas registrita, &#285;i aperos &#265;erete post validigo de la respondeculoj de la retejo.',
'form_prop_envoyer' => 'Sendi mesa&#285;on',
'form_prop_indiquer_email' => 'Bonvolu indiki validan retpo&#349;tadreson',
'form_prop_indiquer_nom_site' => 'Bonvolu indiki la nomon de la retejo.',
'form_prop_indiquer_sujet' => 'Bonvolu indiki temon',
'form_prop_message_envoye' => 'Mesa&#285;o sendita',
'form_prop_nom_site' => 'Nomo de la retejo',
'form_prop_non_enregistre' => 'Via propono ne estis registrita.',
'form_prop_sujet' => 'Temo',
'form_prop_url_site' => 'Adreso (URL) de la retejo',
'forum_acces_refuse' => 'Vi ne plu havas alir-rajton al tiuj &#265;i forumoj.',
'forum_attention_dix_caracteres' => '<b>Atentu&nbsp;!</b> via mesa&#285;o devas enhavi almena&#365; dek signojn.',
'forum_attention_trois_caracteres' => '<b>Atentu&nbsp;!</b> via titolo devas enhavi almena&#365; tri signojn.',
'forum_attention_trop_caracteres' => '<b>Atentu&nbsp;!</b> via mesa&#285;o estas tro longa (@compte@ signoj)&nbsp;: por esti registrita, &#285;i ne preteratingu @max@ signojn.',
'forum_avez_selectionne' => 'Vi selektis&nbsp;:',
'forum_cliquer_retour' => 'Musklaku <a href=\'@retour_forum@\'>&#265;i tie</a> por da&#365;rigi.',
'forum_forum' => 'forumo',
'forum_info_modere' => 'Tiu &#265;i forumo estas apriore moderigata: via kontribuo aperos nur post validigo far de mastrumanto de la forumo.',
'forum_lien_hyper' => '<b>Hiperligo</b> (nedeviga)',
'forum_message_definitif' => 'Definitiva mesa&#285;o: sendu al la forumo',
'forum_message_trop_long' => 'Via mesa&#285;o estas tro longa. La maksimuma longeco estas 20.000 signojn.',
'forum_ne_repondez_pas' => 'Ne respondu al tiu &#265;i retletero, sed en la forumo &#265;e la jena adreso:',
'forum_non_inscrit' => 'Vi ne estas registrita, a&#365; la adreso a&#365; la pasvorto ne &#285;ustas.',
'forum_page_url' => '(Se via mesa&#285;o rilatas al artikolo publikigita &#265;e la reto, a&#365; al pa&#285;o donanta pli da informoj, bonvolu indiki &#265;i-poste la titolon de la pa&#285;o kaj ties ret-adreson.)',
'forum_par_auteur' => 'de @auteur@',
'forum_poste_par' => 'Mesa&#285;o post&eacute;@parauteur@ reage al via artikolo &laquo; @titre@ &raquo;.',
'forum_probleme_database' => 'Datenbazo-problemo, via mesa&#285;o ne estas registrita.',
'forum_qui_etes_vous' => '<b>Kiu vi estas?</b> (nedeviga)',
'forum_texte' => 'Teksto de via mesa&#285;o:',
'forum_titre' => 'Titolo:',
'forum_titre_erreur' => 'Eraro...',
'forum_url' => 'URL:',
'forum_valider' => 'Validigi tiun elekton',
'forum_voir_avant' => 'Vidi tiun &#265;i mesa&#285;on anta&#365; ol sendi &#285;in',
'forum_votre_email' => 'Via retpo&#349;tadreso:',
'forum_votre_nom' => 'Via nomo (a&#365; salutnomo):',
'forum_vous_enregistrer' => 'Por partopreni en ;
  tiu &#265;i forumo, vi devas anta&#365;e registri&#285;i. Bonvolu
  indiki &#265;i-sube la personan ensalutilon kiu estis
  sendita al vi. Se vi ne estas registrita, vi devas',
'forum_vous_inscrire' => 'registri&#285;i.',

// I
'ical_texte_rss_articles' => 'La abondosiero (backend-dosiero) de la artikoloj de tiu retejo troveblas &#265;e la retadreso :',
'ical_texte_rss_articles2' => 'Sube, vi povas trovi abonligojn por gvati evoluadon de artikoloj el &#265;iu rubriko de la retejo:',
'ical_texte_rss_breves' => 'Krome ekzistas dosiero enhavanta &#265;iujn fulm-informojn de la retejo. Precizigante la rubriko-numeron, vi ricevos nur la fulm-informojn el tiu rubriko.',
'icone_a_suivre' => 'Stabejo',
'icone_admin_site' => 'Reteja administrado',
'icone_agenda' => 'Agendo',
'icone_aide_ligne' => 'Helpilo',
'icone_articles' => 'Artikoloj',
'icone_auteurs' => 'A&#365;toroj',
'icone_breves' => 'Fulm-informoj',
'icone_brouteur' => 'Rapida retumado',
'icone_configuration_site' => 'Konfiguro',
'icone_configurer_site' => 'Konfiguri vian retejon',
'icone_creer_nouvel_auteur' => 'Krei novan a&#365;toron',
'icone_creer_rubrique' => 'Krei novan rubrikon',
'icone_creer_sous_rubrique' => 'Krei sub-rubrikon',
'icone_deconnecter' => 'Elsaluti',
'icone_discussions' => 'Diskutoj',
'icone_doc_rubrique' => 'Dokumentoj de la rubrikoj',
'icone_ecrire_article' => 'Skribi novan artikolon',
'icone_edition_site' => 'Redaktejo',
'icone_forum_administrateur' => 'Forumo de la mastrumantoj',
'icone_forum_suivi' => 'Supervido de la forumoj',
'icone_gestion_langues' => 'Mastrumado de lingvoj',
'icone_informations_personnelles' => 'Personaj datenoj',
'icone_interface_complet' => 'kompleta interfaco',
'icone_interface_simple' => 'Simpla interfaco',
'icone_maintenance_site' => 'Retejo-bontenado',
'icone_messagerie_personnelle' => 'Persona mesa&#285;ilo',
'icone_mots_cles' => '&#348;losilvortoj',
'icone_nouvelle_breve' => 'Skribi novan fulm-informon',
'icone_repartition_actuelle' => 'Afi&#349;i la nunan distribuon',
'icone_repartition_debut' => 'Afi&#349;i la distribuon ekde la komenco',
'icone_repartition_visites' => 'Vizitoj-distribuo',
'icone_rubriques' => 'Rubrikoj',
'icone_sauver_site' => 'Savkopii la retejon',
'icone_site_entier' => 'La tuta retejo',
'icone_sites_references' => 'Referencigitaj retejoj',
'icone_statistiques' => 'Statistikoj de la retejo',
'icone_statistiques_visites' => 'Statistikoj',
'icone_suivi_activite' => 'Gvati vivon de la retejo',
'icone_suivi_actualite' => 'Evoluado de la&nbsp;retejo',
'icone_suivi_forums' => 'Superrigardi/mastrumi la forumojn',
'icone_suivi_pettions' => 'Superrigardi/mastrumi la petskribon',
'icone_suivi_revisions' => 'Modifoj de artikoloj',
'icone_supprimer_document' => 'Forigi tiun dokumenton',
'icone_supprimer_image' => 'Forigi tiun bildon',
'icone_supprimer_message' => 'Forigi tiun mesa&#285;on',
'icone_tous_articles' => '&#264;iuj viaj artikoloj',
'icone_tous_auteur' => '&#264;iuj a&#365;toroj',
'icone_valider_message' => 'Validigi tiun mesa&#285;on',
'icone_visiter_site' => 'Viziti',
'icone_voir_en_ligne' => 'Vidi &#265;eretigite',
'image_tourner_180' => 'Rotacio 180&deg;',
'image_tourner_droite' => '90&deg; rotacio dekstren',
'image_tourner_gauche' => '90&deg; rotacio maldekstren',
'img_indisponible' => 'nedisponebla bildo',
'impossible' => 'ne eblas',
'info_a_suivre' => 'STABEJO&nbsp;&raquo;',
'info_a_valider' => '[validigenda]',
'info_acces_interdit' => 'Malpermesata aliro',
'info_acces_refuse' => 'Rifuzita aliro',
'info_action' => 'Ago : @action@',
'info_administrer_rubriques' => 'Vi povas mastrumi tiun rubrikon kaj ties subrubrikojn',
'info_adresse_non_indiquee' => 'Vi indikis neniun adreson por testi&nbsp;!',
'info_aide' => 'HELPO:',
'info_ajouter_mot' => 'Aldoni tiun vorton',
'info_annonce' => 'ANONCO',
'info_annonces_generales' => '&#284;eneralaj anoncoj&nbsp;:',
'info_article_propose' => 'Proponita artikolo',
'info_article_publie' => 'Publikigita artikolo',
'info_article_redaction' => 'Redaktata artikolo',
'info_article_refuse' => 'Rifuzita artikolo',
'info_article_supprime' => 'Forvi&#349;ita artikolo',
'info_articles' => 'Artikoloj',
'info_articles_a_valider' => 'Validigendaj artikoloj',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'Proponitaj artikoloj',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 'a&#365;toro(j)&nbsp;:',
'info_authentification_ftp' => 'A&#365;tentigo (per FTP).',
'info_bloquer_lien' => 'bloki tiun ligilon',
'info_breves_02' => 'Fulm-informoj',
'info_breves_2' => 'fulm-informoj',
'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
'info_breves_un' => '1 br&egrave;ve', # NEW
'info_breves_valider' => 'Validigendaj fulm-informoj',
'info_connexion_refusee' => 'Konekti&#285;o rifuzata',
'info_contact_developpeur' => 'Bonvolu kontakti programiston.',
'info_contenance' => 'Tiu retejo enhavas&nbsp;:',
'info_contribution' => 'forumaj kontribua&#309;oj',
'info_copyright' => '@spip@ estas libera programo distribuata @lien_gpl@.',
'info_copyright_doc' => 'Por pliaj informoj vidu la retpa&#285;on <a href="@spipnet@">http://www.spip.net/eo</a>.', # MODIF
'info_copyright_gpl' => 'sub licenco GPL',
'info_cours_edition' => 'Viaj redaktataj artikoloj',
'info_creer_repertoire' => 'Bonvolu krei dosieron a&#365; dosierujon kies nomo estu&nbsp;:',
'info_creer_repertoire_2' => 'ene de la subdosierujo <b>@repertoire@</b>, kaj&nbsp;:',
'info_creer_vignette' => 'a&#365;tomata kreo de la vinjeto',
'info_deplier' => 'Malfaldi',
'info_descriptif_nombre' => 'priskribo(j)&nbsp;:',
'info_description' => 'Priskribo&nbsp;:',
'info_description_2' => 'Priskribo&nbsp;:',
'info_dimension' => 'Dimensioj&nbsp;:',
'info_document' => 'Dokumento ',
'info_document_indisponible' => 'Tiu &#265;i dokumento ne disponeblas',
'info_documents' => 'Dokumentoj',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIP ebligas inter&#349;an&#285;on de mesa&#285;oj kaj la starigon de privataj diskutforumoj
 inter la partoprenantoj de la retejo. Vi povas aktivigi a&#365;
 malaktivigi tiun funkcion.',
'info_ecire_message_prive' => 'Skribi privatan mesa&#285;on',
'info_email_invalide' => 'Nevalida retpo&#349;tadreso.',
'info_en_cours_validation' => 'Viaj redaktataj artikoloj',
'info_en_ligne' => 'Nun &#265;erete&nbsp;:',
'info_envoyer_message_prive' => 'Sendi privatan mesa&#285;on al tiu &#265;i a&#365;toro',
'info_erreur_requete' => 'Eraro en la peto: ',
'info_erreur_squelette2' => 'Neniu skeleto <b>@fichier@</b> disponeblas...',
'info_erreur_systeme' => 'Sistemo-eraro (errno @errsys@)',
'info_erreur_systeme2' => 'Eble la fiksdisko plenas, a&#365; la datenbazo estas difektita. <br />
 <font color=\'red\'>Provu<a href=\'@script@\'>ripari la datenbazon</a>,
 a&#365; kontaktu vian retgastiganton.</font></br>',
'info_fini' => 'Finite !',
'info_format_image' => 'Bildaj formatoj uzeblaj por krei vinjetojn&nbsp;: @gd_formats@.',
'info_format_non_defini' => 'nedefinita formato',
'info_grand_ecran' => 'Granda ekrano',
'info_image_aide' => 'HELPILO',
'info_image_process_titre' => 'Metodo pri vinjet-farado',
'info_impossible_lire_page' => '<b>Eraro!</b> Ne eblas legi la pa&#285;on <tt> <html>@test_proxy@</html> </tt> tra la prokura servilo <tt>',
'info_inclusion_directe' => 'Rekta inkludo&nbsp;:',
'info_inclusion_vignette' => 'Inkludo de la vinjeto&nbsp;:',
'info_installation_systeme_publication' => 'Instalo de la publikiga sistemo...',
'info_installer_documents' => 'Vi povas a&#365;tomate instali &#265;iujn dokumentojn trovi&#285;antajn en la dosiero @upload@.',
'info_installer_ftp' => 'Kiel mastrumanto, vi povas instali (FTP-e) dosierojn en la dosierujon @upload@ kaj poste rekte selekti ilin &#265;i tie.',
'info_installer_images' => 'Vi povas instali bildojn je la formatoj JPEG, GIF kaj PNG.',
'info_installer_images_dossier' => 'Instali bildojn en la dosierujon @upload@ por povi ilin selekti &#265;i tie.',
'info_installer_tous_documents' => 'Instali &#265;iujn dokumentojn',
'info_interface_complete' => 'kompleta interfaco',
'info_interface_simple' => 'Simpla interfaco',
'info_joindre_document_article' => 'Vi povas ligi kun tiu artikolo dokumentojn tiajn, kiaj',
'info_joindre_document_rubrique' => 'Vi povas ligi kun tiu rubriko dokumentojn tiajn, kiaj',
'info_joindre_documents_article' => 'Vi povas ligi kun tiu artikolo dokumentojn tiajn, kiaj&nbsp;:',
'info_l_article' => 'la artikolo',
'info_la_breve' => 'la fulm-informo',
'info_la_rubrique' => 'la rubriko',
'info_langue_principale' => '&#264;efa lingvo de la retejo',
'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ bilderoj',
'info_les_auteurs_1' => 'de @les_auteurs@',
'info_logo_format_interdit' => 'Nur vinjetoj je formatoj @formats@ estas permesataj.',
'info_logo_max_poids' => 'Vinjetoj devige pezu malpli ol @maxi@ (tiu dosiero pezas @actuel@).',
'info_logo_max_taille' => 'Vinjetoj devige pezu malpli ol @maxi@ (tiu dosiero pezas @actuel@).',
'info_mail_fournisseur' => 'vi@retalir-provizisto.com',
'info_message_2' => 'MESA&#284;O',
'info_message_supprime' => 'FORIGITA MESA&#284;O',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Dato de &#265;eretigo&nbsp;: ',
'info_modification_parametres_securite' => 'modifoj de la sekuraj parametroj',
'info_mois_courant' => 'En la kuranta monato :',
'info_mot_cle_ajoute' => 'La jena &#349;losilvorto estas ligita kun',
'info_multi_herit' => 'Defa&#365;lta lingvo',
'info_multi_langues_soulignees' => 'Por la <u>substrekitaj lingvoj</u>, &#265;iuj tekstoj de la interfaco estas tradukitaj. Kiam vi elektas tiujn lingvojn, multaj elementoj de la publika retejo (datenoj, formularoj) estos a&#365;tomate tradukitaj. Por la nesubstrekitaj lingvoj, tiuj elementoj afi&#349;i&#285;os en la &#265;efa lingvo de la retejo.',
'info_multilinguisme' => 'Multlingvismo',
'info_nom_non_utilisateurs_connectes' => 'Via nomo ne aperas en la listo de la ensalutintaj uzantoj.',
'info_nom_utilisateurs_connectes' => 'Via nomo aperas en la listo de la ensalutintaj uzantoj.',
'info_nombre_en_ligne' => 'Nun ensalutintaj&nbsp;:',
'info_non_resultat' => 'Neniu rezulto por "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'Vi ne uzas la internan mesa&#285;ilon de tiu retejo.',
'info_nouveau_message' => 'VI HAVAS NOVAN MESA&#284;ON',
'info_nouveaux_messages' => 'VI HAVAS @total_messages@ NOVA(J)N MESA&#284;O(J)N',
'info_numero_abbreviation' => 'N&deg;&nbsp;',
'info_obligatoire' => 'Tiu &#265;i informo estas deviga',
'info_panne_site_syndique' => 'Abonligita retejo paneas',
'info_pense_bete' => 'MEMORIGILO',
'info_petit_ecran' => 'Eta ekrano',
'info_petition_close' => 'Petskribo fermita',
'info_pixels' => 'bilderoj',
'info_plusieurs_mots_trouves' => 'Pluraj &#349;losilvortoj trovitaj por "@cherche_mot@":',
'info_popularite_5' => 'populareco&nbsp;:',
'info_portfolio' => 'Bildaro',
'info_portfolio_automatique' => 'A&#365;tomata bildaro&nbsp;:',
'info_premier_resultat' => '[@debut_limit@ unuaj rezultoj el @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ unuaj rezultoj el @total@]',
'info_probleme_grave' => 'problemo de',
'info_propose_1' => '[@nom_site_spip@] Proponas: @titre@',
'info_propose_2' => 'Proponita artikolo
---------------',
'info_propose_3' => 'La artikolo "@titre@" estas proponita por publikigo.',
'info_propose_4' => 'Vi estas petata konsulti &#285;in kaj doni vian opinion',
'info_propose_5' => 'en la forumo ligita al &#285;i. &#284;i estas disponebla el la adreso:',
'info_publie_01' => 'La artikolo "@titre@" estis validigita de @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] PUBLIKIGAS: @titre@',
'info_publie_2' => 'Artikolo publikigita
--------------',
'info_rechercher' => 'Ser&#265;i',
'info_rechercher_02' => 'Ser&#265;i&nbsp;:',
'info_remplacer_vignette' => 'Anstata&#365;i la defa&#365;ltan vinjeton per propra vinjeto&nbsp;:',
'info_retablir_lien' => 'Resta&#365;ri tiun ligilon',
'info_retirer_mot' => 'Forigi tiun vorton',
'info_retirer_mots' => 'Forigi &#265;iujn vortojn',
'info_rubriques_nb' => '@nb@ rubriques', # NEW
'info_rubriques_un' => '1 rubrique', # NEW
'info_sans_titre_2' => 'sen titolo',
'info_selectionner_fichier' => 'Vi povas selekti dosieron el la dosierujo @upload@',
'info_selectionner_fichier_2' => 'Elektu dosieron&nbsp;:',
'info_signature_supprimee' => 'Subskribo forvi&#349;ita',
'info_signature_supprimee_erreur' => 'Eraro&nbsp;: tiu &#265;i forvi&#349;cela kodo kongruas kun neniu subskribo',
'info_site_attente' => 'Retejo atendanta validigon',
'info_site_reference' => 'Retejo rete referencigita',
'info_site_refuse' => 'Rifuzita retejo',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'Referencigi retejon',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'forigi la vinjeton',
'info_symbole_bleu' => 'La <b>blua</b> simbolo indikas <b>memorigilon</b> : tio estas al vi persone adresata memoriga mesa&#285;o.',
'info_symbole_jaune' => 'La <b>flava</b> simbolo indikas <b>anoncon al &#265;iuj redaktantoj</b>&nbsp;: modifebla de &#265;iuj mastrumantoj, kaj videbla de &#265;iuj redaktantoj.',
'info_symbole_vert' => 'La <b>verda</b> simbolo indikas la <b>mesa&#285;ojn inter&#349;an&#285;itajn kun aliaj uzantoj</b> de la retejo.',
'info_syndication' => 'abonrilato&nbsp;:',
'info_syndication_articles' => 'artikolo(j)',
'info_telecharger' => 'Al&#349;uti ekde via komputilo&nbsp;:',
'info_telecharger_nouveau_logo' => 'Al&#349;uti novan vinjeton&nbsp;:',
'info_telecharger_ordinateur' => 'Al&#349;uti ekde via komputilo&nbsp;:',
'info_tous_resultats_enregistres' => '[&#265;iuj rezultoj estas registritaj]',
'info_tout_afficher' => '&#264;ion afi&#349;i',
'info_travaux_texte' => 'Tiu retejo ne jam estas konfigurita. Bonvolu reveni poste...',
'info_travaux_titre' => 'Retejo prilaborata ',
'info_trop_resultat' => 'Tro da rezultoj por "@cherche_mot@"; bonvolu fajnigi la ser&#265;okriteriojn.',
'info_utilisation_messagerie_interne' => 'Vi uzas la internan po&#349;ton de tiu &#265;i retejo.',
'info_valider_lien' => 'validigi tiun &#265;i ligilon',
'info_verifier_image' => ', bonvolu kontroli &#265;u viaj bildoj estas trafe transigitaj.',
'info_vignette_defaut' => 'Defa&#365;lta vinjeto',
'info_vignette_personnalisee' => 'Persona vinjeto',
'info_visite' => 'vizito :',
'info_visites' => 'vizitoj :',
'info_vos_rendez_vous' => 'Viaj estontaj rendevuoj',
'info_zoom' => 'zomo',
'infos_vos_pense_bete' => 'Viaj memorigiloj',
'item_breve_proposee' => 'Proponita fulm-informo',

// L
'lien_afficher_icones_seuls' => 'Afi&#349;i nur la piktogramojn',
'lien_afficher_texte_icones' => 'Afi&#349;i la piktogramojn kaj la tekston',
'lien_afficher_texte_seul' => 'Afi&#349;i nur la tekston',
'lien_liberer' => 'liberigi',
'lien_liberer_tous' => 'liberigi tiujn artikolojn',
'lien_nouvea_pense_bete' => 'NOVA MEMORIGILO',
'lien_nouveau_message' => 'NOVA MESA&#284;O',
'lien_nouvelle_annonce' => 'NOVA ANONCO',
'lien_petitions' => 'PETSKRIBO',
'lien_popularite' => 'populareco&nbsp;: @popularite@%',
'lien_racine_site' => 'RADIKO DE LA RETEJO',
'lien_reessayer' => 'reprovi',
'lien_repondre_message' => 'Respondi al tiu mesa&#285;o',
'lien_supprimer' => 'forigi',
'lien_tout_afficher' => 'Afi&#349;i &#265;ion',
'lien_visite_site' => 'viziti tiun retejon',
'lien_visites' => '@visites@&nbsp;vizitoj',
'lien_voir_auteur' => 'Vidi tiun a&#365;toron',
'ligne' => 'Linio',
'login' => 'Ensaluti',
'login_acces_prive' => 'aliro al la privata spaco',
'login_autre_identifiant' => 'ensaluti per alia salutnomo',
'login_cookie_accepte' => 'Bonvolu agordi vian retumilon por ke &#285;i akceptu ilin (almena&#365; por tiu &#265;i retejo).',
'login_cookie_oblige' => 'Por sekure ensaluti&#285;i en tiu retejo, vi devas akcepti la kuketojn.',
'login_deconnexion_ok' => 'Elsalutinta.',
'login_erreur_pass' => 'Pasvort-eraro.',
'login_espace_prive' => 'privata spaco',
'login_identifiant_inconnu' => 'La salutnomo &laquo; @login@ &raquo; estas nekonata.',
'login_login' => 'Salutnomo:',
'login_login2' => 'Salutnomo (ensalutilo por konekti&#285;i al la retejo)&nbsp;:',
'login_login_pass_incorrect' => '(Salutnomo a&#365; pasvorto ne valida.)',
'login_motpasseoublie' => '&#265;u&nbsp;pasvorto&nbsp;forgesita&nbsp;?',
'login_non_securise' => 'Atentu, tiu formularo ne estas sekurigita;.
   Se vi ne volas ke via pasvorto estu fra&#365;de
   interkaptita &#265;e la reto, bonvolu aktivigi
   Javascript-on en via retumilo',
'login_nouvelle_tentative' => 'Nova provo',
'login_par_ici' => 'Vi estas registrita... &#265;i tien...',
'login_pass2' => 'Pasvorto&nbsp;:',
'login_preferez_refuser' => '<b>Se vi preferas rifuzi kuketojn</b>, alia konektometodo (malpli sekura) estas je via dispono&nbsp;:',
'login_recharger' => 'fre&#349;igi tiun &#265;i pa&#285;on',
'login_rester_identifie' => 'Resti ensalutinta kelkajn tagojn',
'login_retour_public' => 'Reen al la publika spaco',
'login_retour_site' => 'Reen al la publika spaco',
'login_retoursitepublic' => 'reen&nbsp;al&nbsp;la&nbsp;publika&nbsp;spaco',
'login_sans_cookiie' => 'Ensaluto sen kuketo',
'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
'login_sinscrire' => 'registri&#285;i',
'login_test_navigateur' => 'testo retumilo/rekonekti&#285;o',
'login_verifiez_navigateur' => '(Kontrolu tamen ke via retumilo ne memoras pri via pasvorto...)',

// M
'masquer_colonne' => 'Ka&#349;i tiun &#265;i kolumnon',
'masquer_trad' => 'ka&#349;i la tradukojn',
'module_fichiers_langues' => 'Dosieroj de lingvo',

// N
'navigateur_pas_redirige' => 'Se via retumilo ne redirekti&#285;as, da&#365;rigu musklakante &#265;i tie.',
'numero' => 'Numero',

// O
'occurence' => 'Trafo',
'onglet_affacer_base' => 'Forigi la datenbazon',
'onglet_auteur' => 'La a&#365;toro',
'onglet_contenu_site' => 'Enhavo de la retejo',
'onglet_evolution_visite_mod' => 'Evoluado',
'onglet_fonctions_avances' => 'Ampleksaj funkcioj',
'onglet_informations_personnelles' => 'Personaj datenoj',
'onglet_interactivite' => 'Interagado',
'onglet_messagerie' => 'Mesa&#285;ilo',
'onglet_messages_internes' => 'Internaj mesa&#285;oj',
'onglet_messages_publics' => 'Publikaj mesa&#285;oj',
'onglet_messages_vide' => 'Sentekstaj mesa&#285;oj',
'onglet_origine_visites' => 'Deveno de la vizitintoj',
'onglet_repartition_debut' => 'dekomence',
'onglet_repartition_lang' => 'Distribuo la&#365; lingvoj',
'onglet_repartition_rubrique' => 'Distribuo la&#365; rubrikoj',
'onglet_save_restaur_base' => 'Savkopii/resta&#365;ri la datenbazon',
'onglet_vider_cache' => 'Malplenigi la staplon',
'ortho_trop_de_fautes2' => 'Bonvolu korekti la plej evidentajn erarojn kaj poste reprovu.',

// P
'pass_choix_pass' => 'Bonvolu elekti vian novan pasvorton:',
'pass_erreur' => 'Eraro',
'pass_erreur_acces_refuse' => '<b>Eraro:</b> vi ne plu havas aliron al tiu retejo.',
'pass_erreur_code_inconnu' => '<b>Eraro:</b> tiu kodo kongruas kun neniu el la vizitantoj rajtantaj aliri tiun &#265;i retejon.',
'pass_erreur_non_enregistre' => '<b>Eraro :</b> la retpo&#349;tadreso <tt>@email_oubli@</tt> ne estas registrita &#265;i tie.',
'pass_erreur_non_valide' => '<b>Eraro :</b> tiu retpo&#349;tadreso <tt>@email_oubli@</tt> ne validas!',
'pass_erreur_probleme_technique' => '<b>Eraro :</b> pro teknika problemo, la retmesa&#285;o ne povas esti sendata.',
'pass_espace_prive_bla' => 'La privata spaco de tiu &#265;i retejo estas malfermita al
  vizitantoj, post ties registri&#285;o. Tio farita, vi povos
  konsulti la redaktatajn artikolojn, proponi artikolojn
  kaj partopreni en &#265;iuj forumoj.',
'pass_forum_bla' => 'Vi petis por kontribui en forumo
  rezervita al registritaj vizitantoj.',
'pass_indiquez_cidessous' => 'Indiku &#265;i-sube la retpo&#349;tadreson la&#365; kiu vi
   anta&#365;e registri&#285;is. Vi
   ricevos retmesa&#285;on kiu indikos al vi kion fari por
   reakiri vian alir-rajton.',
'pass_mail_passcookie' => '(tio &#265;i estas a&#365;tomata mesa&#285;o)
Por reakiri alireblon al la retejo
@nom_site_spip@ (@adresse_site@)

Bonvolu iri al la jena adreso:

    @sendcookie@

Vi povos tiam entajpi novan pasvorton
kaj ensaluti.

',
'pass_mot_oublie' => 'Pasvorto forgesita',
'pass_nouveau_enregistre' => 'Via nova pasvorto estas registrita.',
'pass_nouveau_pass' => 'Nova pasvorto',
'pass_ok' => 'JES',
'pass_oubli_mot' => 'Pasvorto-forgeso',
'pass_quitter_fenetre' => 'Forlasi tiun fenestron',
'pass_rappel_login' => 'Memoru: via ensalutilo (salutnomo) estas &laquo; @login@ &raquo;.',
'pass_recevoir_mail' => 'Vi ricevos retmesa&#285;on indikantan al vi kiel retrovi vian aliron al la retejo.',
'pass_retour_public' => 'Reen al la publika spaco',
'pass_rien_a_faire_ici' => 'Nenion por fari &#265;i tie.',
'pass_vousinscrire' => 'Registri&#285;i &#265;e tiu retejo',
'precedent' => 'anta&#365;an',
'previsualisation' => 'Anta&#365;rigardo',
'previsualiser' => 'Anta&#365;rigardi',

// R
'retour' => 'Reen',

// S
'spip_conforme_dtd' => 'SPIP konsideras tiun dokumenton konforma al sia DOCTYPE :',
'squelette' => 'skeleto',
'squelette_inclus_ligne' => 'skeleto inkluzivita, linio',
'squelette_ligne' => 'skeleto, linio',
'stats_visites_et_popularite' => '@visites@ vizitoj&nbsp;; populareco&nbsp;: @popularite@',
'suivant' => 'sekvanta',

// T
'taille_ko' => '@taille@&nbsp;kb',
'taille_mo' => '@taille@&nbsp;Mb',
'taille_octets' => '@taille@&nbsp;bitokoj',
'texte_actualite_site_1' => 'Kiam vi estos kutimi&#285;inta kun la interfaco, vi povos musklaki sur &laquo;',
'texte_actualite_site_2' => 'kompleta interfaco',
'texte_actualite_site_3' => '&raquo; por malfermi pliajn eblecojn.',
'texte_creation_automatique_vignette' => 'La a&#365;tomata kreado de anta&#365;rigardaj vinjetoj estas aktivigita &#265;e tiu &#265;i retejo. Se vi instalas pere de tiu &#265;i formularo bildojn je la formato(j) @gd_formats@, ili estos akompanataj de vinjeto kun maksimuma grandeco de @taille_preview@&nbsp;bilderoj.',
'texte_documents_associes' => 'La sekvantaj dokumentoj estas asociitaj al la artikolo,
    sed ili ne estis rekte enmetitaj en &#285;in.
    La&#365; la enpa&#285;igo de la publika spaco,
    ili povos aperi en formo de alkro&#265;itaj dokumentoj.',
'texte_erreur_mise_niveau_base' => 'Datenbazo-eraro dum la alniveligo.
  La bildo <b>@fichier@</b> ne trans&#349;uti&#285;is (artikolo @id_article@).
  Bone notu tiun referencon, reprovu la alniveligon,
  kaj fine kontrolu ke la bildoj plu aperu
en la artikoloj.',
'texte_erreur_visiteur' => 'Vi provis eniri la privatan spacon pere de ne alir-rajtiga salutnomo.',
'texte_inc_auth_1' => 'Vi ensalutis la&#365; la
  salutnomo <b>@auth_login@</b>, sed tiu ne/ne plu ekzistas en la datenbazo.
  Provu',
'texte_inc_auth_2' => 'rekonekti&#285;i',
'texte_inc_auth_3' => ', post esti eventuale ferminta kaj
  restartiginta via retumilon.',
'texte_inc_config' => 'La &#349;an&#285;oj faritaj en tiuj &#265;i pa&#285;oj influas grave la
 funkciadon de via retejo. Ni konsilas al vi ne plu interveni anta&#365; ol esti pli
 kutimi&#285;inta pri la funkciado de la SPIP-sistemo. <br /><br /><b>Pli
 &#285;enerale, estas tre konsilinde lasi la mastrumadon de tiuj &#265;i pa&#285;oj
sub la respondeco de la &#265;efa retejestro .</b>',
'texte_inc_meta_1' => 'La sistemo detektis eraron dum skribado de la dosiero <code>@fichier@</code>. Bonvolu, kiel mastrumanto de la retejo,',
'texte_inc_meta_2' => 'kontroli la skriborajtojn',
'texte_inc_meta_3' => 'en la dosierujo <code>@repertoire@</code>.',
'texte_statut_en_cours_redaction' => 'Redaktataj',
'texte_statut_poubelle' => 'en rubujo',
'texte_statut_propose_evaluation' => 'proponita por taksado',
'texte_statut_publie' => 'rete publikigita',
'texte_statut_refuse' => 'rifuzita',
'titre_ajouter_mot_cle' => 'ALDONI &#348;LOSILVORTON:',
'titre_breve_proposee' => 'Proponita fulm-informo',
'titre_breve_publiee' => 'Publikigita fulm-informo',
'titre_breve_refusee' => 'Rifuzita fulm-informo',
'titre_cadre_raccourcis' => 'RAPIDAJ ALIROJ:',
'titre_changer_couleur_interface' => '&#348;an&#285;i la koloron de la interfaco',
'titre_forum' => 'Forumo',
'titre_image_admin_article' => 'Vi povas mastrumi tiun &#265;i artikolon',
'titre_image_administrateur' => 'Mastrumanto',
'titre_image_aide' => 'Helpo pri tiu elemento',
'titre_image_auteur_supprime' => 'A&#365;toro forigita',
'titre_image_redacteur' => 'Redaktanto sen alireblo',
'titre_image_redacteur_02' => 'Redaktanto',
'titre_image_visiteur' => 'Vizitanto',
'titre_joindre_document' => 'ALDONI DOKUMENTON',
'titre_liens_entrants' => 'Enirintaj ligoj',
'titre_mots_cles' => '&#348;LOSILVORTOJ',
'titre_probleme_technique' => 'Atentu&nbsp;: teknika problemo  (SQL-servilo) malhelpas la aliron al tiu parto de la retejo. Dankon pro via komprenemo.',
'titre_publier_document' => 'PUBLIKIGI DOKUMENTON EN TIU &#264;I RUBRIKO',
'titre_signatures_attente' => 'Subskriboj validotaj',
'titre_signatures_confirmees' => 'Subskriboj konfirmitaj',
'titre_statistiques' => 'Statistikoj de la retejo',
'titre_titre_document' => 'Titolo de la dokumento&nbsp;:',
'todo' => 'venonta',
'trad_reference' => '(referenca artikolo)',

// Z
'zbug_balise_b_aval' => '&nbsp;: posta B marko',
'zbug_balise_inexistante' => 'eraro @from@: la etikedo " #@balise@ " ne ekzistas', # MODIF
'zbug_balise_sans_argument' => 'Mankas argumento en la etikedo @balise@',
'zbug_boucle' => 'iteracio',
'zbug_boucle_recursive_undef' => 'nedifinita rekursia iteracio', # MODIF
'zbug_calcul' => 'komputado',
'zbug_champ_hors_boucle' => 'Kampo @champ@ eksteras iteracion',
'zbug_champ_hors_motif' => 'Kampo @champ@ eksteras iteracion, kies formo estas @motif@', # MODIF
'zbug_code' => 'kodo',
'zbug_critere_inconnu' => 'nekonata kriterio @critere@', # MODIF
'zbug_distant_interdit' => 'ago &#265;e tiu ekstera datenbazo malpermesata', # MODIF
'zbug_doublon_table_sans_cle_primaire' => 'duobloj uzitaj &#265;e tabelo, kiu ne havas simplan &#265;ef&#349;losilon', # MODIF
'zbug_doublon_table_sans_index' => 'duobla&#309;oj en la datentabelo sen indekso', # MODIF
'zbug_erreur_boucle_double' => 'BOUCLE@id@: duobla difino', # MODIF
'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: mankas fermcela marko', # MODIF
'zbug_erreur_boucle_syntaxe' => 'Ne valida iteracia sintakso', # MODIF
'zbug_erreur_compilation' => 'Kompil-eraro',
'zbug_erreur_execution_page' => 'eraro dum plenumo de pa&#285;-afi&#349;o', # MODIF
'zbug_erreur_filtre' => 'Eraro : filtrilo <b>&laquo; @filtre@ &raquo;</b> nedifinita', # MODIF
'zbug_erreur_meme_parent' => '{meme_parent} nur apliki&#285;as je iteracioj (FORUMS) a&#365; (RUBRIQUES)', # MODIF
'zbug_erreur_squelette' => 'Eraro(j) en la skeleto',
'zbug_hors_compilation' => 'Ne kompilita',
'zbug_info_erreur_squelette' => 'Eraro &#265;e la retejo',
'zbug_inversion_ordre_inexistant' => 'inversigo de ne ekzistanta ordo', # MODIF
'zbug_pagination_sans_critere' => '#PAGINATION senkriteria {pa&#285;numerado} a&#365; uzata en rekursia iteracio', # MODIF
'zbug_parametres_inclus_incorrects' => 'Ne korektaj inkludaj parametroj', # MODIF
'zbug_profile' => 'Kalkulda&#365;ro&nbsp;: @time@',
'zbug_resultat' => 'rezulto',
'zbug_serveur_indefini' => 'nedifinata SQL servilo', # MODIF
'zbug_statistiques' => 'statistikoj pri SQL-informpetoj ordigitaj la&#365; da&#365;ro',
'zbug_table_inconnue' => 'nekonata SQL &laquo; @table@ &raquo; tabelo',
'zxml_connus_attributs' => 'konataj atributoj',
'zxml_de' => 'de',
'zxml_inconnu_attribut' => 'nekonataj atributoj',
'zxml_inconnu_balise' => 'ne konita marko',
'zxml_inconnu_entite' => 'ne konata ento',
'zxml_inconnu_id' => 'ne konata ID',
'zxml_mais_de' => 'sed',
'zxml_non_conforme' => 'ne kongrua kun la motivo',
'zxml_non_fils' => 'ne estas filo de',
'zxml_nonvide_balise' => 'ne malplena marko',
'zxml_obligatoire_attribut' => 'deviga atributo sed foresta en',
'zxml_succession_fils_incorrecte' => 'sinsekvo de filoj korekta',
'zxml_survoler' => 'superflugi por ekvidi korekta&#309;ojn',
'zxml_valeur_attribut' => 'atributa valoro',
'zxml_vide_balise' => 'malplena marko',
'zxml_vu' => 'anta&#365;e vidita'
);

?>
